"""ConnectionParametricStudyTool"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7936

_CONNECTION_PARAMETRIC_STUDY_TOOL = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ParametricStudyTools",
    "ConnectionParametricStudyTool",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
        _4617,
        _4618,
        _4623,
        _4625,
        _4630,
        _4635,
        _4638,
        _4640,
        _4643,
        _4646,
        _4651,
        _4654,
        _4658,
        _4660,
        _4661,
        _4674,
        _4679,
        _4683,
        _4686,
        _4687,
        _4690,
        _4693,
        _4708,
        _4715,
        _4718,
        _4725,
        _4727,
        _4732,
        _4734,
        _4737,
        _4740,
        _4743,
        _4752,
        _4758,
        _4761,
    )
    from mastapy._private.system_model.connections_and_sockets import _2532
    from mastapy._private.utility_gui import _2089
    from mastapy._private.utility_gui.charts import _2098, _2104, _2106

    Self = TypeVar("Self", bound="ConnectionParametricStudyTool")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConnectionParametricStudyTool._Cast_ConnectionParametricStudyTool",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConnectionParametricStudyTool",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConnectionParametricStudyTool:
    """Special nested class for casting ConnectionParametricStudyTool to subclasses."""

    __parent__: "ConnectionParametricStudyTool"

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_shaft_to_mountable_component_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4617.AbstractShaftToMountableComponentConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4617,
        )

        return self.__parent__._cast(
            _4617.AbstractShaftToMountableComponentConnectionParametricStudyTool
        )

    @property
    def agma_gleason_conical_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4618.AGMAGleasonConicalGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4618,
        )

        return self.__parent__._cast(
            _4618.AGMAGleasonConicalGearMeshParametricStudyTool
        )

    @property
    def belt_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4623.BeltConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4623,
        )

        return self.__parent__._cast(_4623.BeltConnectionParametricStudyTool)

    @property
    def bevel_differential_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4625.BevelDifferentialGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4625,
        )

        return self.__parent__._cast(_4625.BevelDifferentialGearMeshParametricStudyTool)

    @property
    def bevel_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4630.BevelGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4630,
        )

        return self.__parent__._cast(_4630.BevelGearMeshParametricStudyTool)

    @property
    def clutch_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4635.ClutchConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4635,
        )

        return self.__parent__._cast(_4635.ClutchConnectionParametricStudyTool)

    @property
    def coaxial_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4638.CoaxialConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4638,
        )

        return self.__parent__._cast(_4638.CoaxialConnectionParametricStudyTool)

    @property
    def concept_coupling_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4640.ConceptCouplingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4640,
        )

        return self.__parent__._cast(_4640.ConceptCouplingConnectionParametricStudyTool)

    @property
    def concept_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4643.ConceptGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4643,
        )

        return self.__parent__._cast(_4643.ConceptGearMeshParametricStudyTool)

    @property
    def conical_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4646.ConicalGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4646,
        )

        return self.__parent__._cast(_4646.ConicalGearMeshParametricStudyTool)

    @property
    def coupling_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4651.CouplingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4651,
        )

        return self.__parent__._cast(_4651.CouplingConnectionParametricStudyTool)

    @property
    def cvt_belt_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4654.CVTBeltConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4654,
        )

        return self.__parent__._cast(_4654.CVTBeltConnectionParametricStudyTool)

    @property
    def cycloidal_disc_central_bearing_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4658.CycloidalDiscCentralBearingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4658,
        )

        return self.__parent__._cast(
            _4658.CycloidalDiscCentralBearingConnectionParametricStudyTool
        )

    @property
    def cycloidal_disc_planetary_bearing_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4660.CycloidalDiscPlanetaryBearingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4660,
        )

        return self.__parent__._cast(
            _4660.CycloidalDiscPlanetaryBearingConnectionParametricStudyTool
        )

    @property
    def cylindrical_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4661.CylindricalGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4661,
        )

        return self.__parent__._cast(_4661.CylindricalGearMeshParametricStudyTool)

    @property
    def face_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4674.FaceGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4674,
        )

        return self.__parent__._cast(_4674.FaceGearMeshParametricStudyTool)

    @property
    def gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4679.GearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4679,
        )

        return self.__parent__._cast(_4679.GearMeshParametricStudyTool)

    @property
    def hypoid_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4683.HypoidGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4683,
        )

        return self.__parent__._cast(_4683.HypoidGearMeshParametricStudyTool)

    @property
    def inter_mountable_component_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4686.InterMountableComponentConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4686,
        )

        return self.__parent__._cast(
            _4686.InterMountableComponentConnectionParametricStudyTool
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4687.KlingelnbergCycloPalloidConicalGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4687,
        )

        return self.__parent__._cast(
            _4687.KlingelnbergCycloPalloidConicalGearMeshParametricStudyTool
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4690.KlingelnbergCycloPalloidHypoidGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4690,
        )

        return self.__parent__._cast(
            _4690.KlingelnbergCycloPalloidHypoidGearMeshParametricStudyTool
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4693.KlingelnbergCycloPalloidSpiralBevelGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4693,
        )

        return self.__parent__._cast(
            _4693.KlingelnbergCycloPalloidSpiralBevelGearMeshParametricStudyTool
        )

    @property
    def part_to_part_shear_coupling_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4715.PartToPartShearCouplingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4715,
        )

        return self.__parent__._cast(
            _4715.PartToPartShearCouplingConnectionParametricStudyTool
        )

    @property
    def planetary_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4718.PlanetaryConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4718,
        )

        return self.__parent__._cast(_4718.PlanetaryConnectionParametricStudyTool)

    @property
    def ring_pins_to_disc_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4725.RingPinsToDiscConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4725,
        )

        return self.__parent__._cast(_4725.RingPinsToDiscConnectionParametricStudyTool)

    @property
    def rolling_ring_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4727.RollingRingConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4727,
        )

        return self.__parent__._cast(_4727.RollingRingConnectionParametricStudyTool)

    @property
    def shaft_to_mountable_component_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4732.ShaftToMountableComponentConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4732,
        )

        return self.__parent__._cast(
            _4732.ShaftToMountableComponentConnectionParametricStudyTool
        )

    @property
    def spiral_bevel_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4734.SpiralBevelGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4734,
        )

        return self.__parent__._cast(_4734.SpiralBevelGearMeshParametricStudyTool)

    @property
    def spring_damper_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4737.SpringDamperConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4737,
        )

        return self.__parent__._cast(_4737.SpringDamperConnectionParametricStudyTool)

    @property
    def straight_bevel_diff_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4740.StraightBevelDiffGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4740,
        )

        return self.__parent__._cast(_4740.StraightBevelDiffGearMeshParametricStudyTool)

    @property
    def straight_bevel_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4743.StraightBevelGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4743,
        )

        return self.__parent__._cast(_4743.StraightBevelGearMeshParametricStudyTool)

    @property
    def torque_converter_connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4752.TorqueConverterConnectionParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4752,
        )

        return self.__parent__._cast(_4752.TorqueConverterConnectionParametricStudyTool)

    @property
    def worm_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4758.WormGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4758,
        )

        return self.__parent__._cast(_4758.WormGearMeshParametricStudyTool)

    @property
    def zerol_bevel_gear_mesh_parametric_study_tool(
        self: "CastSelf",
    ) -> "_4761.ZerolBevelGearMeshParametricStudyTool":
        from mastapy._private.system_model.analyses_and_results.parametric_study_tools import (
            _4761,
        )

        return self.__parent__._cast(_4761.ZerolBevelGearMeshParametricStudyTool)

    @property
    def connection_parametric_study_tool(
        self: "CastSelf",
    ) -> "ConnectionParametricStudyTool":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConnectionParametricStudyTool(_7936.ConnectionAnalysisCase):
    """ConnectionParametricStudyTool

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONNECTION_PARAMETRIC_STUDY_TOOL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def design_of_experiments_chart(self: "Self") -> "_2098.NDChartDefinition":
        """mastapy.utility_gui.charts.NDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DesignOfExperimentsChart")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def linear_sweep_chart_2d(self: "Self") -> "_2106.TwoDChartDefinition":
        """mastapy.utility_gui.charts.TwoDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LinearSweepChart2D")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def linear_sweep_chart_3d(self: "Self") -> "_2104.ThreeDChartDefinition":
        """mastapy.utility_gui.charts.ThreeDChartDefinition

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "LinearSweepChart3D")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2532.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2532.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def data_logger(self: "Self") -> "_2089.DataLoggerWithCharts":
        """mastapy.utility_gui.DataLoggerWithCharts

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "DataLogger")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def parametric_study_tool(self: "Self") -> "_4708.ParametricStudyTool":
        """mastapy.system_model.analyses_and_results.parametric_study_tools.ParametricStudyTool

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ParametricStudyTool")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ConnectionParametricStudyTool":
        """Cast to another type.

        Returns:
            _Cast_ConnectionParametricStudyTool
        """
        return _Cast_ConnectionParametricStudyTool(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.part_model.couplings._2860 import BeltDrive
    from mastapy._private.system_model.part_model.couplings._2861 import BeltDriveType
    from mastapy._private.system_model.part_model.couplings._2862 import Clutch
    from mastapy._private.system_model.part_model.couplings._2863 import ClutchHalf
    from mastapy._private.system_model.part_model.couplings._2864 import ClutchType
    from mastapy._private.system_model.part_model.couplings._2865 import ConceptCoupling
    from mastapy._private.system_model.part_model.couplings._2866 import (
        ConceptCouplingHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2867 import (
        ConceptCouplingHalfPositioning,
    )
    from mastapy._private.system_model.part_model.couplings._2868 import Coupling
    from mastapy._private.system_model.part_model.couplings._2869 import CouplingHalf
    from mastapy._private.system_model.part_model.couplings._2870 import (
        CrowningSpecification,
    )
    from mastapy._private.system_model.part_model.couplings._2871 import CVT
    from mastapy._private.system_model.part_model.couplings._2872 import CVTPulley
    from mastapy._private.system_model.part_model.couplings._2873 import (
        PartToPartShearCoupling,
    )
    from mastapy._private.system_model.part_model.couplings._2874 import (
        PartToPartShearCouplingHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2875 import (
        PitchErrorFlankOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2876 import Pulley
    from mastapy._private.system_model.part_model.couplings._2877 import (
        RigidConnectorSettings,
    )
    from mastapy._private.system_model.part_model.couplings._2878 import (
        RigidConnectorStiffnessType,
    )
    from mastapy._private.system_model.part_model.couplings._2879 import (
        RigidConnectorTiltStiffnessTypes,
    )
    from mastapy._private.system_model.part_model.couplings._2880 import (
        RigidConnectorToothLocation,
    )
    from mastapy._private.system_model.part_model.couplings._2881 import (
        RigidConnectorToothSpacingType,
    )
    from mastapy._private.system_model.part_model.couplings._2882 import (
        RigidConnectorTypes,
    )
    from mastapy._private.system_model.part_model.couplings._2883 import RollingRing
    from mastapy._private.system_model.part_model.couplings._2884 import (
        RollingRingAssembly,
    )
    from mastapy._private.system_model.part_model.couplings._2885 import (
        ShaftHubConnection,
    )
    from mastapy._private.system_model.part_model.couplings._2886 import (
        SplineFitOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2887 import (
        SplineHalfManufacturingError,
    )
    from mastapy._private.system_model.part_model.couplings._2888 import (
        SplineLeadRelief,
    )
    from mastapy._private.system_model.part_model.couplings._2889 import (
        SplinePitchErrorInputType,
    )
    from mastapy._private.system_model.part_model.couplings._2890 import (
        SplinePitchErrorOptions,
    )
    from mastapy._private.system_model.part_model.couplings._2891 import SpringDamper
    from mastapy._private.system_model.part_model.couplings._2892 import (
        SpringDamperHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2893 import Synchroniser
    from mastapy._private.system_model.part_model.couplings._2894 import (
        SynchroniserCone,
    )
    from mastapy._private.system_model.part_model.couplings._2895 import (
        SynchroniserHalf,
    )
    from mastapy._private.system_model.part_model.couplings._2896 import (
        SynchroniserPart,
    )
    from mastapy._private.system_model.part_model.couplings._2897 import (
        SynchroniserSleeve,
    )
    from mastapy._private.system_model.part_model.couplings._2898 import TorqueConverter
    from mastapy._private.system_model.part_model.couplings._2899 import (
        TorqueConverterPump,
    )
    from mastapy._private.system_model.part_model.couplings._2900 import (
        TorqueConverterSpeedRatio,
    )
    from mastapy._private.system_model.part_model.couplings._2901 import (
        TorqueConverterTurbine,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.part_model.couplings._2860": ["BeltDrive"],
        "_private.system_model.part_model.couplings._2861": ["BeltDriveType"],
        "_private.system_model.part_model.couplings._2862": ["Clutch"],
        "_private.system_model.part_model.couplings._2863": ["ClutchHalf"],
        "_private.system_model.part_model.couplings._2864": ["ClutchType"],
        "_private.system_model.part_model.couplings._2865": ["ConceptCoupling"],
        "_private.system_model.part_model.couplings._2866": ["ConceptCouplingHalf"],
        "_private.system_model.part_model.couplings._2867": [
            "ConceptCouplingHalfPositioning"
        ],
        "_private.system_model.part_model.couplings._2868": ["Coupling"],
        "_private.system_model.part_model.couplings._2869": ["CouplingHalf"],
        "_private.system_model.part_model.couplings._2870": ["CrowningSpecification"],
        "_private.system_model.part_model.couplings._2871": ["CVT"],
        "_private.system_model.part_model.couplings._2872": ["CVTPulley"],
        "_private.system_model.part_model.couplings._2873": ["PartToPartShearCoupling"],
        "_private.system_model.part_model.couplings._2874": [
            "PartToPartShearCouplingHalf"
        ],
        "_private.system_model.part_model.couplings._2875": ["PitchErrorFlankOptions"],
        "_private.system_model.part_model.couplings._2876": ["Pulley"],
        "_private.system_model.part_model.couplings._2877": ["RigidConnectorSettings"],
        "_private.system_model.part_model.couplings._2878": [
            "RigidConnectorStiffnessType"
        ],
        "_private.system_model.part_model.couplings._2879": [
            "RigidConnectorTiltStiffnessTypes"
        ],
        "_private.system_model.part_model.couplings._2880": [
            "RigidConnectorToothLocation"
        ],
        "_private.system_model.part_model.couplings._2881": [
            "RigidConnectorToothSpacingType"
        ],
        "_private.system_model.part_model.couplings._2882": ["RigidConnectorTypes"],
        "_private.system_model.part_model.couplings._2883": ["RollingRing"],
        "_private.system_model.part_model.couplings._2884": ["RollingRingAssembly"],
        "_private.system_model.part_model.couplings._2885": ["ShaftHubConnection"],
        "_private.system_model.part_model.couplings._2886": ["SplineFitOptions"],
        "_private.system_model.part_model.couplings._2887": [
            "SplineHalfManufacturingError"
        ],
        "_private.system_model.part_model.couplings._2888": ["SplineLeadRelief"],
        "_private.system_model.part_model.couplings._2889": [
            "SplinePitchErrorInputType"
        ],
        "_private.system_model.part_model.couplings._2890": ["SplinePitchErrorOptions"],
        "_private.system_model.part_model.couplings._2891": ["SpringDamper"],
        "_private.system_model.part_model.couplings._2892": ["SpringDamperHalf"],
        "_private.system_model.part_model.couplings._2893": ["Synchroniser"],
        "_private.system_model.part_model.couplings._2894": ["SynchroniserCone"],
        "_private.system_model.part_model.couplings._2895": ["SynchroniserHalf"],
        "_private.system_model.part_model.couplings._2896": ["SynchroniserPart"],
        "_private.system_model.part_model.couplings._2897": ["SynchroniserSleeve"],
        "_private.system_model.part_model.couplings._2898": ["TorqueConverter"],
        "_private.system_model.part_model.couplings._2899": ["TorqueConverterPump"],
        "_private.system_model.part_model.couplings._2900": [
            "TorqueConverterSpeedRatio"
        ],
        "_private.system_model.part_model.couplings._2901": ["TorqueConverterTurbine"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "BeltDrive",
    "BeltDriveType",
    "Clutch",
    "ClutchHalf",
    "ClutchType",
    "ConceptCoupling",
    "ConceptCouplingHalf",
    "ConceptCouplingHalfPositioning",
    "Coupling",
    "CouplingHalf",
    "CrowningSpecification",
    "CVT",
    "CVTPulley",
    "PartToPartShearCoupling",
    "PartToPartShearCouplingHalf",
    "PitchErrorFlankOptions",
    "Pulley",
    "RigidConnectorSettings",
    "RigidConnectorStiffnessType",
    "RigidConnectorTiltStiffnessTypes",
    "RigidConnectorToothLocation",
    "RigidConnectorToothSpacingType",
    "RigidConnectorTypes",
    "RollingRing",
    "RollingRingAssembly",
    "ShaftHubConnection",
    "SplineFitOptions",
    "SplineHalfManufacturingError",
    "SplineLeadRelief",
    "SplinePitchErrorInputType",
    "SplinePitchErrorOptions",
    "SpringDamper",
    "SpringDamperHalf",
    "Synchroniser",
    "SynchroniserCone",
    "SynchroniserHalf",
    "SynchroniserPart",
    "SynchroniserSleeve",
    "TorqueConverter",
    "TorqueConverterPump",
    "TorqueConverterSpeedRatio",
    "TorqueConverterTurbine",
)



"""MeasurementSettings"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item, overridable
from mastapy._private.utility import _1820
from mastapy._private.utility.units_and_measurements import _1831

_MEASUREMENT_SETTINGS = python_net_import(
    "SMT.MastaAPI.Utility.UnitsAndMeasurements", "MeasurementSettings"
)

if TYPE_CHECKING:
    from typing import Any, Tuple, Type, TypeVar, Union

    from mastapy._private.units_and_measurements import _7959
    from mastapy._private.utility import _1821

    Self = TypeVar("Self", bound="MeasurementSettings")
    CastSelf = TypeVar(
        "CastSelf", bound="MeasurementSettings._Cast_MeasurementSettings"
    )


__docformat__ = "restructuredtext en"
__all__ = ("MeasurementSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MeasurementSettings:
    """Special nested class for casting MeasurementSettings to subclasses."""

    __parent__: "MeasurementSettings"

    @property
    def per_machine_settings(self: "CastSelf") -> "_1820.PerMachineSettings":
        return self.__parent__._cast(_1820.PerMachineSettings)

    @property
    def persistent_singleton(self: "CastSelf") -> "_1821.PersistentSingleton":
        from mastapy._private.utility import _1821

        return self.__parent__._cast(_1821.PersistentSingleton)

    @property
    def measurement_settings(self: "CastSelf") -> "MeasurementSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class MeasurementSettings(_1820.PerMachineSettings):
    """MeasurementSettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MEASUREMENT_SETTINGS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def large_number_cutoff(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LargeNumberCutoff")

        if temp is None:
            return 0.0

        return temp

    @large_number_cutoff.setter
    @exception_bridge
    @enforce_parameter_types
    def large_number_cutoff(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LargeNumberCutoff",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def number_decimal_separator(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "NumberDecimalSeparator")

        if temp is None:
            return ""

        return temp

    @number_decimal_separator.setter
    @exception_bridge
    @enforce_parameter_types
    def number_decimal_separator(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberDecimalSeparator",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def number_group_separator(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "NumberGroupSeparator")

        if temp is None:
            return ""

        return temp

    @number_group_separator.setter
    @exception_bridge
    @enforce_parameter_types
    def number_group_separator(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberGroupSeparator",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def sample_input(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SampleInput")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def sample_output(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SampleOutput")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def selected_measurement(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_MeasurementBase":
        """ListWithSelectedItem[mastapy.utility.units_and_measurements.MeasurementBase]"""
        temp = pythonnet_property_get(self.wrapped, "SelectedMeasurement")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_MeasurementBase",
        )(temp)

    @selected_measurement.setter
    @exception_bridge
    @enforce_parameter_types
    def selected_measurement(self: "Self", value: "_1831.MeasurementBase") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_MeasurementBase.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "SelectedMeasurement", value)

    @property
    @exception_bridge
    def show_trailing_zeros(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowTrailingZeros")

        if temp is None:
            return False

        return temp

    @show_trailing_zeros.setter
    @exception_bridge
    @enforce_parameter_types
    def show_trailing_zeros(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowTrailingZeros",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def small_number_cutoff(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "SmallNumberCutoff")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @small_number_cutoff.setter
    @exception_bridge
    @enforce_parameter_types
    def small_number_cutoff(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "SmallNumberCutoff", value)

    @property
    @exception_bridge
    def current_selected_measurement(self: "Self") -> "_1831.MeasurementBase":
        """mastapy.utility.units_and_measurements.MeasurementBase

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CurrentSelectedMeasurement")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @exception_bridge
    def default_to_imperial(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "DefaultToImperial")

    @exception_bridge
    def default_to_metric(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "DefaultToMetric")

    @exception_bridge
    @enforce_parameter_types
    def find_measurement_by_name(self: "Self", name: "str") -> "_1831.MeasurementBase":
        """mastapy.utility.units_and_measurements.MeasurementBase

        Args:
            name (str)
        """
        name = str(name)
        method_result = pythonnet_method_call(
            self.wrapped, "FindMeasurementByName", name if name else ""
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @exception_bridge
    @enforce_parameter_types
    def get_measurement(
        self: "Self", measurement_type: "_7959.MeasurementType"
    ) -> "_1831.MeasurementBase":
        """mastapy.utility.units_and_measurements.MeasurementBase

        Args:
            measurement_type (mastapy.units_and_measurements.MeasurementType)
        """
        measurement_type = conversion.mp_to_pn_enum(
            measurement_type, "SMT.MastaAPIUtility.UnitsAndMeasurements.MeasurementType"
        )
        method_result = pythonnet_method_call(
            self.wrapped, "GetMeasurement", measurement_type
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @property
    def cast_to(self: "Self") -> "_Cast_MeasurementSettings":
        """Cast to another type.

        Returns:
            _Cast_MeasurementSettings
        """
        return _Cast_MeasurementSettings(self)



"""GearSetParetoOptimiser"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.gear_set_pareto_optimiser import _1031, _1036
from mastapy._private.gears.rating import _467

_GEAR_SET_PARETO_OPTIMISER = python_net_import(
    "SMT.MastaAPI.Gears.GearSetParetoOptimiser", "GearSetParetoOptimiser"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.gears.gear_designs import _1076
    from mastapy._private.gears.gear_set_pareto_optimiser import (
        _1030,
        _1033,
        _1038,
        _1064,
        _1065,
    )

    Self = TypeVar("Self", bound="GearSetParetoOptimiser")
    CastSelf = TypeVar(
        "CastSelf", bound="GearSetParetoOptimiser._Cast_GearSetParetoOptimiser"
    )


__docformat__ = "restructuredtext en"
__all__ = ("GearSetParetoOptimiser",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GearSetParetoOptimiser:
    """Special nested class for casting GearSetParetoOptimiser to subclasses."""

    __parent__: "GearSetParetoOptimiser"

    @property
    def design_space_search_base(self: "CastSelf") -> "_1031.DesignSpaceSearchBase":
        return self.__parent__._cast(_1031.DesignSpaceSearchBase)

    @property
    def cylindrical_gear_set_pareto_optimiser(
        self: "CastSelf",
    ) -> "_1030.CylindricalGearSetParetoOptimiser":
        from mastapy._private.gears.gear_set_pareto_optimiser import _1030

        return self.__parent__._cast(_1030.CylindricalGearSetParetoOptimiser)

    @property
    def face_gear_set_pareto_optimiser(
        self: "CastSelf",
    ) -> "_1033.FaceGearSetParetoOptimiser":
        from mastapy._private.gears.gear_set_pareto_optimiser import _1033

        return self.__parent__._cast(_1033.FaceGearSetParetoOptimiser)

    @property
    def hypoid_gear_set_pareto_optimiser(
        self: "CastSelf",
    ) -> "_1038.HypoidGearSetParetoOptimiser":
        from mastapy._private.gears.gear_set_pareto_optimiser import _1038

        return self.__parent__._cast(_1038.HypoidGearSetParetoOptimiser)

    @property
    def spiral_bevel_gear_set_pareto_optimiser(
        self: "CastSelf",
    ) -> "_1064.SpiralBevelGearSetParetoOptimiser":
        from mastapy._private.gears.gear_set_pareto_optimiser import _1064

        return self.__parent__._cast(_1064.SpiralBevelGearSetParetoOptimiser)

    @property
    def straight_bevel_gear_set_pareto_optimiser(
        self: "CastSelf",
    ) -> "_1065.StraightBevelGearSetParetoOptimiser":
        from mastapy._private.gears.gear_set_pareto_optimiser import _1065

        return self.__parent__._cast(_1065.StraightBevelGearSetParetoOptimiser)

    @property
    def gear_set_pareto_optimiser(self: "CastSelf") -> "GearSetParetoOptimiser":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class GearSetParetoOptimiser(
    _1031.DesignSpaceSearchBase[
        _467.AbstractGearSetRating, _1036.GearSetOptimiserCandidate
    ]
):
    """GearSetParetoOptimiser

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR_SET_PARETO_OPTIMISER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def number_of_designs_with_gears_which_cannot_be_manufactured_from_cutters(
        self: "Self",
    ) -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfDesignsWithGearsWhichCannotBeManufacturedFromCutters"
        )

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def remove_candidates_which_cannot_be_manufactured_with_cutters_from_database(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped,
            "RemoveCandidatesWhichCannotBeManufacturedWithCuttersFromDatabase",
        )

        if temp is None:
            return False

        return temp

    @remove_candidates_which_cannot_be_manufactured_with_cutters_from_database.setter
    @exception_bridge
    @enforce_parameter_types
    def remove_candidates_which_cannot_be_manufactured_with_cutters_from_database(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "RemoveCandidatesWhichCannotBeManufacturedWithCuttersFromDatabase",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def remove_candidates_with_warnings(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "RemoveCandidatesWithWarnings")

        if temp is None:
            return False

        return temp

    @remove_candidates_with_warnings.setter
    @exception_bridge
    @enforce_parameter_types
    def remove_candidates_with_warnings(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "RemoveCandidatesWithWarnings",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def selected_candidate_geometry(self: "Self") -> "_1076.GearSetDesign":
        """mastapy.gears.gear_designs.GearSetDesign

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "SelectedCandidateGeometry")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def all_candidate_gear_sets(self: "Self") -> "List[_1076.GearSetDesign]":
        """List[mastapy.gears.gear_designs.GearSetDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AllCandidateGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def candidate_gear_sets(self: "Self") -> "List[_1076.GearSetDesign]":
        """List[mastapy.gears.gear_designs.GearSetDesign]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CandidateGearSets")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @exception_bridge
    def add_chart(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "AddChart")

    @exception_bridge
    def reset_charts(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "ResetCharts")

    @property
    def cast_to(self: "Self") -> "_Cast_GearSetParetoOptimiser":
        """Cast to another type.

        Returns:
            _Cast_GearSetParetoOptimiser
        """
        return _Cast_GearSetParetoOptimiser(self)



"""ConnectionStabilityAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.analysis_cases import _7939

_CONNECTION_STABILITY_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StabilityAnalyses",
    "ConnectionStabilityAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.analysis_cases import _7936
    from mastapy._private.system_model.analyses_and_results.stability_analyses import (
        _4076,
        _4077,
        _4082,
        _4084,
        _4089,
        _4094,
        _4097,
        _4099,
        _4102,
        _4105,
        _4110,
        _4114,
        _4118,
        _4119,
        _4121,
        _4128,
        _4133,
        _4137,
        _4140,
        _4141,
        _4144,
        _4147,
        _4157,
        _4160,
        _4167,
        _4169,
        _4174,
        _4176,
        _4179,
        _4182,
        _4185,
        _4188,
        _4197,
        _4203,
        _4206,
    )
    from mastapy._private.system_model.connections_and_sockets import _2532

    Self = TypeVar("Self", bound="ConnectionStabilityAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConnectionStabilityAnalysis._Cast_ConnectionStabilityAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConnectionStabilityAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConnectionStabilityAnalysis:
    """Special nested class for casting ConnectionStabilityAnalysis to subclasses."""

    __parent__: "ConnectionStabilityAnalysis"

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7939.ConnectionStaticLoadAnalysisCase":
        return self.__parent__._cast(_7939.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7936.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7936,
        )

        return self.__parent__._cast(_7936.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def abstract_shaft_to_mountable_component_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4076.AbstractShaftToMountableComponentConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4076,
        )

        return self.__parent__._cast(
            _4076.AbstractShaftToMountableComponentConnectionStabilityAnalysis
        )

    @property
    def agma_gleason_conical_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4077.AGMAGleasonConicalGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4077,
        )

        return self.__parent__._cast(_4077.AGMAGleasonConicalGearMeshStabilityAnalysis)

    @property
    def belt_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4082.BeltConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4082,
        )

        return self.__parent__._cast(_4082.BeltConnectionStabilityAnalysis)

    @property
    def bevel_differential_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4084.BevelDifferentialGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4084,
        )

        return self.__parent__._cast(_4084.BevelDifferentialGearMeshStabilityAnalysis)

    @property
    def bevel_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4089.BevelGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4089,
        )

        return self.__parent__._cast(_4089.BevelGearMeshStabilityAnalysis)

    @property
    def clutch_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4094.ClutchConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4094,
        )

        return self.__parent__._cast(_4094.ClutchConnectionStabilityAnalysis)

    @property
    def coaxial_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4097.CoaxialConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4097,
        )

        return self.__parent__._cast(_4097.CoaxialConnectionStabilityAnalysis)

    @property
    def concept_coupling_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4099.ConceptCouplingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4099,
        )

        return self.__parent__._cast(_4099.ConceptCouplingConnectionStabilityAnalysis)

    @property
    def concept_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4102.ConceptGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4102,
        )

        return self.__parent__._cast(_4102.ConceptGearMeshStabilityAnalysis)

    @property
    def conical_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4105.ConicalGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4105,
        )

        return self.__parent__._cast(_4105.ConicalGearMeshStabilityAnalysis)

    @property
    def coupling_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4110.CouplingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4110,
        )

        return self.__parent__._cast(_4110.CouplingConnectionStabilityAnalysis)

    @property
    def cvt_belt_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4114.CVTBeltConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4114,
        )

        return self.__parent__._cast(_4114.CVTBeltConnectionStabilityAnalysis)

    @property
    def cycloidal_disc_central_bearing_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4118.CycloidalDiscCentralBearingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4118,
        )

        return self.__parent__._cast(
            _4118.CycloidalDiscCentralBearingConnectionStabilityAnalysis
        )

    @property
    def cycloidal_disc_planetary_bearing_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4119.CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4119,
        )

        return self.__parent__._cast(
            _4119.CycloidalDiscPlanetaryBearingConnectionStabilityAnalysis
        )

    @property
    def cylindrical_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4121.CylindricalGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4121,
        )

        return self.__parent__._cast(_4121.CylindricalGearMeshStabilityAnalysis)

    @property
    def face_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4128.FaceGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4128,
        )

        return self.__parent__._cast(_4128.FaceGearMeshStabilityAnalysis)

    @property
    def gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4133.GearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4133,
        )

        return self.__parent__._cast(_4133.GearMeshStabilityAnalysis)

    @property
    def hypoid_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4137.HypoidGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4137,
        )

        return self.__parent__._cast(_4137.HypoidGearMeshStabilityAnalysis)

    @property
    def inter_mountable_component_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4140.InterMountableComponentConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4140,
        )

        return self.__parent__._cast(
            _4140.InterMountableComponentConnectionStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4141.KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4141,
        )

        return self.__parent__._cast(
            _4141.KlingelnbergCycloPalloidConicalGearMeshStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4144.KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4144,
        )

        return self.__parent__._cast(
            _4144.KlingelnbergCycloPalloidHypoidGearMeshStabilityAnalysis
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4147.KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4147,
        )

        return self.__parent__._cast(
            _4147.KlingelnbergCycloPalloidSpiralBevelGearMeshStabilityAnalysis
        )

    @property
    def part_to_part_shear_coupling_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4157.PartToPartShearCouplingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4157,
        )

        return self.__parent__._cast(
            _4157.PartToPartShearCouplingConnectionStabilityAnalysis
        )

    @property
    def planetary_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4160.PlanetaryConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4160,
        )

        return self.__parent__._cast(_4160.PlanetaryConnectionStabilityAnalysis)

    @property
    def ring_pins_to_disc_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4167.RingPinsToDiscConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4167,
        )

        return self.__parent__._cast(_4167.RingPinsToDiscConnectionStabilityAnalysis)

    @property
    def rolling_ring_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4169.RollingRingConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4169,
        )

        return self.__parent__._cast(_4169.RollingRingConnectionStabilityAnalysis)

    @property
    def shaft_to_mountable_component_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4174.ShaftToMountableComponentConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4174,
        )

        return self.__parent__._cast(
            _4174.ShaftToMountableComponentConnectionStabilityAnalysis
        )

    @property
    def spiral_bevel_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4176.SpiralBevelGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4176,
        )

        return self.__parent__._cast(_4176.SpiralBevelGearMeshStabilityAnalysis)

    @property
    def spring_damper_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4179.SpringDamperConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4179,
        )

        return self.__parent__._cast(_4179.SpringDamperConnectionStabilityAnalysis)

    @property
    def straight_bevel_diff_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4185.StraightBevelDiffGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4185,
        )

        return self.__parent__._cast(_4185.StraightBevelDiffGearMeshStabilityAnalysis)

    @property
    def straight_bevel_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4188.StraightBevelGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4188,
        )

        return self.__parent__._cast(_4188.StraightBevelGearMeshStabilityAnalysis)

    @property
    def torque_converter_connection_stability_analysis(
        self: "CastSelf",
    ) -> "_4197.TorqueConverterConnectionStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4197,
        )

        return self.__parent__._cast(_4197.TorqueConverterConnectionStabilityAnalysis)

    @property
    def worm_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4203.WormGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4203,
        )

        return self.__parent__._cast(_4203.WormGearMeshStabilityAnalysis)

    @property
    def zerol_bevel_gear_mesh_stability_analysis(
        self: "CastSelf",
    ) -> "_4206.ZerolBevelGearMeshStabilityAnalysis":
        from mastapy._private.system_model.analyses_and_results.stability_analyses import (
            _4206,
        )

        return self.__parent__._cast(_4206.ZerolBevelGearMeshStabilityAnalysis)

    @property
    def connection_stability_analysis(
        self: "CastSelf",
    ) -> "ConnectionStabilityAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ConnectionStabilityAnalysis(_7939.ConnectionStaticLoadAnalysisCase):
    """ConnectionStabilityAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONNECTION_STABILITY_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2532.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2532.Connection":
        """mastapy.system_model.connections_and_sockets.Connection

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def stability_analysis(self: "Self") -> "_4182.StabilityAnalysis":
        """mastapy.system_model.analyses_and_results.stability_analyses.StabilityAnalysis

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StabilityAnalysis")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ConnectionStabilityAnalysis":
        """Cast to another type.

        Returns:
            _Cast_ConnectionStabilityAnalysis
        """
        return _Cast_ConnectionStabilityAnalysis(self)



"""BearingStiffnessMatrixReporter"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private import _0
from mastapy._private._internal import conversion, utility

_BEARING_STIFFNESS_MATRIX_REPORTER = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults", "BearingStiffnessMatrixReporter"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private.bearings.bearing_results import _2206

    Self = TypeVar("Self", bound="BearingStiffnessMatrixReporter")
    CastSelf = TypeVar(
        "CastSelf",
        bound="BearingStiffnessMatrixReporter._Cast_BearingStiffnessMatrixReporter",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BearingStiffnessMatrixReporter",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BearingStiffnessMatrixReporter:
    """Special nested class for casting BearingStiffnessMatrixReporter to subclasses."""

    __parent__: "BearingStiffnessMatrixReporter"

    @property
    def bearing_stiffness_matrix_reporter(
        self: "CastSelf",
    ) -> "BearingStiffnessMatrixReporter":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class BearingStiffnessMatrixReporter(_0.APIBase):
    """BearingStiffnessMatrixReporter

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEARING_STIFFNESS_MATRIX_REPORTER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def axial_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AxialStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_radial_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumRadialStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def maximum_tilt_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MaximumTiltStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def minimum_radial_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MinimumRadialStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def minimum_tilt_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "MinimumTiltStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def name(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Name")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def radial_stiffness_variation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "RadialStiffnessVariation")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_xx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_xy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_xz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_x_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_x_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_x_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessXThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_yx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_yy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_yz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_y_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_y_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_y_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessYThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_zx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_zy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_zz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_z_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_z_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_z_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessZThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_xx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_xy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_xz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_x_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_x_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_x_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaXThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_yx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_yy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_yz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_y_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_y_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_y_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaYThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_zx(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_zy(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_zz(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_z_theta_x(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZThetaX")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_z_theta_y(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZThetaY")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def stiffness_theta_z_theta_z(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "StiffnessThetaZThetaZ")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def tilt_stiffness_variation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TiltStiffnessVariation")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def torsional_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TorsionalStiffness")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def rows(self: "Self") -> "List[_2206.StiffnessRow]":
        """List[mastapy.bearings.bearing_results.StiffnessRow]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Rows")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_BearingStiffnessMatrixReporter":
        """Cast to another type.

        Returns:
            _Cast_BearingStiffnessMatrixReporter
        """
        return _Cast_BearingStiffnessMatrixReporter(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3147 import (
        AbstractAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3148 import (
        AbstractShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3149 import (
        AbstractShaftOrHousingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3150 import (
        AbstractShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3151 import (
        AGMAGleasonConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3152 import (
        AGMAGleasonConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3153 import (
        AGMAGleasonConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3154 import (
        AssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3155 import (
        BearingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3156 import (
        BeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3157 import (
        BeltDriveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3158 import (
        BevelDifferentialGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3159 import (
        BevelDifferentialGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3160 import (
        BevelDifferentialGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3161 import (
        BevelDifferentialPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3162 import (
        BevelDifferentialSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3163 import (
        BevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3164 import (
        BevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3165 import (
        BevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3166 import (
        BoltCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3167 import (
        BoltedJointCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3168 import (
        ClutchCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3169 import (
        ClutchConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3170 import (
        ClutchHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3171 import (
        CoaxialConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3172 import (
        ComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3173 import (
        ConceptCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3174 import (
        ConceptCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3175 import (
        ConceptCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3176 import (
        ConceptGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3177 import (
        ConceptGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3178 import (
        ConceptGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3179 import (
        ConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3180 import (
        ConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3181 import (
        ConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3182 import (
        ConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3183 import (
        ConnectorCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3184 import (
        CouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3185 import (
        CouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3186 import (
        CouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3187 import (
        CVTBeltConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3188 import (
        CVTCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3189 import (
        CVTPulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3190 import (
        CycloidalAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3191 import (
        CycloidalDiscCentralBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3192 import (
        CycloidalDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3193 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3194 import (
        CylindricalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3195 import (
        CylindricalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3196 import (
        CylindricalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3197 import (
        CylindricalPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3198 import (
        DatumCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3199 import (
        DutyCycleEfficiencyResults,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3200 import (
        ExternalCADModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3201 import (
        FaceGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3202 import (
        FaceGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3203 import (
        FaceGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3204 import (
        FEPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3205 import (
        FlexiblePinAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3206 import (
        GearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3207 import (
        GearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3208 import (
        GearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3209 import (
        GuideDxfModelCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3210 import (
        HypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3211 import (
        HypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3212 import (
        HypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3213 import (
        InterMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3214 import (
        KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3215 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3216 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3217 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3218 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3219 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3220 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3221 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3222 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3223 import (
        MassDiscCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3224 import (
        MeasurementComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3225 import (
        MicrophoneArrayCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3226 import (
        MicrophoneCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3227 import (
        MountableComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3228 import (
        OilSealCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3229 import (
        PartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3230 import (
        PartToPartShearCouplingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3231 import (
        PartToPartShearCouplingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3232 import (
        PartToPartShearCouplingHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3233 import (
        PlanetaryConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3234 import (
        PlanetaryGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3235 import (
        PlanetCarrierCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3236 import (
        PointLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3237 import (
        PowerLoadCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3238 import (
        PulleyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3239 import (
        RingPinsCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3240 import (
        RingPinsToDiscConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3241 import (
        RollingRingAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3242 import (
        RollingRingCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3243 import (
        RollingRingConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3244 import (
        RootAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3245 import (
        ShaftCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3246 import (
        ShaftDutyCycleSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3247 import (
        ShaftHubConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3248 import (
        ShaftToMountableComponentConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3249 import (
        SpecialisedAssemblyCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3250 import (
        SpiralBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3251 import (
        SpiralBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3252 import (
        SpiralBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3253 import (
        SpringDamperCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3254 import (
        SpringDamperConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3255 import (
        SpringDamperHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3256 import (
        StraightBevelDiffGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3257 import (
        StraightBevelDiffGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3258 import (
        StraightBevelDiffGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3259 import (
        StraightBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3260 import (
        StraightBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3261 import (
        StraightBevelGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3262 import (
        StraightBevelPlanetGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3263 import (
        StraightBevelSunGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3264 import (
        SynchroniserCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3265 import (
        SynchroniserHalfCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3266 import (
        SynchroniserPartCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3267 import (
        SynchroniserSleeveCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3268 import (
        TorqueConverterCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3269 import (
        TorqueConverterConnectionCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3270 import (
        TorqueConverterPumpCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3271 import (
        TorqueConverterTurbineCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3272 import (
        UnbalancedMassCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3273 import (
        VirtualComponentCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3274 import (
        WormGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3275 import (
        WormGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3276 import (
        WormGearSetCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3277 import (
        ZerolBevelGearCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3278 import (
        ZerolBevelGearMeshCompoundSystemDeflection,
    )
    from mastapy._private.system_model.analyses_and_results.system_deflections.compound._3279 import (
        ZerolBevelGearSetCompoundSystemDeflection,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.system_deflections.compound._3147": [
            "AbstractAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3148": [
            "AbstractShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3149": [
            "AbstractShaftOrHousingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3150": [
            "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3151": [
            "AGMAGleasonConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3152": [
            "AGMAGleasonConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3153": [
            "AGMAGleasonConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3154": [
            "AssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3155": [
            "BearingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3156": [
            "BeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3157": [
            "BeltDriveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3158": [
            "BevelDifferentialGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3159": [
            "BevelDifferentialGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3160": [
            "BevelDifferentialGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3161": [
            "BevelDifferentialPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3162": [
            "BevelDifferentialSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3163": [
            "BevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3164": [
            "BevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3165": [
            "BevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3166": [
            "BoltCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3167": [
            "BoltedJointCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3168": [
            "ClutchCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3169": [
            "ClutchConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3170": [
            "ClutchHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3171": [
            "CoaxialConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3172": [
            "ComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3173": [
            "ConceptCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3174": [
            "ConceptCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3175": [
            "ConceptCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3176": [
            "ConceptGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3177": [
            "ConceptGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3178": [
            "ConceptGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3179": [
            "ConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3180": [
            "ConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3181": [
            "ConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3182": [
            "ConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3183": [
            "ConnectorCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3184": [
            "CouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3185": [
            "CouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3186": [
            "CouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3187": [
            "CVTBeltConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3188": [
            "CVTCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3189": [
            "CVTPulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3190": [
            "CycloidalAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3191": [
            "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3192": [
            "CycloidalDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3193": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3194": [
            "CylindricalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3195": [
            "CylindricalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3196": [
            "CylindricalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3197": [
            "CylindricalPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3198": [
            "DatumCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3199": [
            "DutyCycleEfficiencyResults"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3200": [
            "ExternalCADModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3201": [
            "FaceGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3202": [
            "FaceGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3203": [
            "FaceGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3204": [
            "FEPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3205": [
            "FlexiblePinAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3206": [
            "GearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3207": [
            "GearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3208": [
            "GearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3209": [
            "GuideDxfModelCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3210": [
            "HypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3211": [
            "HypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3212": [
            "HypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3213": [
            "InterMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3214": [
            "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3215": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3216": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3217": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3218": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3219": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3220": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3221": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3222": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3223": [
            "MassDiscCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3224": [
            "MeasurementComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3225": [
            "MicrophoneArrayCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3226": [
            "MicrophoneCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3227": [
            "MountableComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3228": [
            "OilSealCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3229": [
            "PartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3230": [
            "PartToPartShearCouplingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3231": [
            "PartToPartShearCouplingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3232": [
            "PartToPartShearCouplingHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3233": [
            "PlanetaryConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3234": [
            "PlanetaryGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3235": [
            "PlanetCarrierCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3236": [
            "PointLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3237": [
            "PowerLoadCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3238": [
            "PulleyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3239": [
            "RingPinsCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3240": [
            "RingPinsToDiscConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3241": [
            "RollingRingAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3242": [
            "RollingRingCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3243": [
            "RollingRingConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3244": [
            "RootAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3245": [
            "ShaftCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3246": [
            "ShaftDutyCycleSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3247": [
            "ShaftHubConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3248": [
            "ShaftToMountableComponentConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3249": [
            "SpecialisedAssemblyCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3250": [
            "SpiralBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3251": [
            "SpiralBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3252": [
            "SpiralBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3253": [
            "SpringDamperCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3254": [
            "SpringDamperConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3255": [
            "SpringDamperHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3256": [
            "StraightBevelDiffGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3257": [
            "StraightBevelDiffGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3258": [
            "StraightBevelDiffGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3259": [
            "StraightBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3260": [
            "StraightBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3261": [
            "StraightBevelGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3262": [
            "StraightBevelPlanetGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3263": [
            "StraightBevelSunGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3264": [
            "SynchroniserCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3265": [
            "SynchroniserHalfCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3266": [
            "SynchroniserPartCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3267": [
            "SynchroniserSleeveCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3268": [
            "TorqueConverterCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3269": [
            "TorqueConverterConnectionCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3270": [
            "TorqueConverterPumpCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3271": [
            "TorqueConverterTurbineCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3272": [
            "UnbalancedMassCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3273": [
            "VirtualComponentCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3274": [
            "WormGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3275": [
            "WormGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3276": [
            "WormGearSetCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3277": [
            "ZerolBevelGearCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3278": [
            "ZerolBevelGearMeshCompoundSystemDeflection"
        ],
        "_private.system_model.analyses_and_results.system_deflections.compound._3279": [
            "ZerolBevelGearSetCompoundSystemDeflection"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSystemDeflection",
    "AbstractShaftCompoundSystemDeflection",
    "AbstractShaftOrHousingCompoundSystemDeflection",
    "AbstractShaftToMountableComponentConnectionCompoundSystemDeflection",
    "AGMAGleasonConicalGearCompoundSystemDeflection",
    "AGMAGleasonConicalGearMeshCompoundSystemDeflection",
    "AGMAGleasonConicalGearSetCompoundSystemDeflection",
    "AssemblyCompoundSystemDeflection",
    "BearingCompoundSystemDeflection",
    "BeltConnectionCompoundSystemDeflection",
    "BeltDriveCompoundSystemDeflection",
    "BevelDifferentialGearCompoundSystemDeflection",
    "BevelDifferentialGearMeshCompoundSystemDeflection",
    "BevelDifferentialGearSetCompoundSystemDeflection",
    "BevelDifferentialPlanetGearCompoundSystemDeflection",
    "BevelDifferentialSunGearCompoundSystemDeflection",
    "BevelGearCompoundSystemDeflection",
    "BevelGearMeshCompoundSystemDeflection",
    "BevelGearSetCompoundSystemDeflection",
    "BoltCompoundSystemDeflection",
    "BoltedJointCompoundSystemDeflection",
    "ClutchCompoundSystemDeflection",
    "ClutchConnectionCompoundSystemDeflection",
    "ClutchHalfCompoundSystemDeflection",
    "CoaxialConnectionCompoundSystemDeflection",
    "ComponentCompoundSystemDeflection",
    "ConceptCouplingCompoundSystemDeflection",
    "ConceptCouplingConnectionCompoundSystemDeflection",
    "ConceptCouplingHalfCompoundSystemDeflection",
    "ConceptGearCompoundSystemDeflection",
    "ConceptGearMeshCompoundSystemDeflection",
    "ConceptGearSetCompoundSystemDeflection",
    "ConicalGearCompoundSystemDeflection",
    "ConicalGearMeshCompoundSystemDeflection",
    "ConicalGearSetCompoundSystemDeflection",
    "ConnectionCompoundSystemDeflection",
    "ConnectorCompoundSystemDeflection",
    "CouplingCompoundSystemDeflection",
    "CouplingConnectionCompoundSystemDeflection",
    "CouplingHalfCompoundSystemDeflection",
    "CVTBeltConnectionCompoundSystemDeflection",
    "CVTCompoundSystemDeflection",
    "CVTPulleyCompoundSystemDeflection",
    "CycloidalAssemblyCompoundSystemDeflection",
    "CycloidalDiscCentralBearingConnectionCompoundSystemDeflection",
    "CycloidalDiscCompoundSystemDeflection",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSystemDeflection",
    "CylindricalGearCompoundSystemDeflection",
    "CylindricalGearMeshCompoundSystemDeflection",
    "CylindricalGearSetCompoundSystemDeflection",
    "CylindricalPlanetGearCompoundSystemDeflection",
    "DatumCompoundSystemDeflection",
    "DutyCycleEfficiencyResults",
    "ExternalCADModelCompoundSystemDeflection",
    "FaceGearCompoundSystemDeflection",
    "FaceGearMeshCompoundSystemDeflection",
    "FaceGearSetCompoundSystemDeflection",
    "FEPartCompoundSystemDeflection",
    "FlexiblePinAssemblyCompoundSystemDeflection",
    "GearCompoundSystemDeflection",
    "GearMeshCompoundSystemDeflection",
    "GearSetCompoundSystemDeflection",
    "GuideDxfModelCompoundSystemDeflection",
    "HypoidGearCompoundSystemDeflection",
    "HypoidGearMeshCompoundSystemDeflection",
    "HypoidGearSetCompoundSystemDeflection",
    "InterMountableComponentConnectionCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSystemDeflection",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSystemDeflection",
    "MassDiscCompoundSystemDeflection",
    "MeasurementComponentCompoundSystemDeflection",
    "MicrophoneArrayCompoundSystemDeflection",
    "MicrophoneCompoundSystemDeflection",
    "MountableComponentCompoundSystemDeflection",
    "OilSealCompoundSystemDeflection",
    "PartCompoundSystemDeflection",
    "PartToPartShearCouplingCompoundSystemDeflection",
    "PartToPartShearCouplingConnectionCompoundSystemDeflection",
    "PartToPartShearCouplingHalfCompoundSystemDeflection",
    "PlanetaryConnectionCompoundSystemDeflection",
    "PlanetaryGearSetCompoundSystemDeflection",
    "PlanetCarrierCompoundSystemDeflection",
    "PointLoadCompoundSystemDeflection",
    "PowerLoadCompoundSystemDeflection",
    "PulleyCompoundSystemDeflection",
    "RingPinsCompoundSystemDeflection",
    "RingPinsToDiscConnectionCompoundSystemDeflection",
    "RollingRingAssemblyCompoundSystemDeflection",
    "RollingRingCompoundSystemDeflection",
    "RollingRingConnectionCompoundSystemDeflection",
    "RootAssemblyCompoundSystemDeflection",
    "ShaftCompoundSystemDeflection",
    "ShaftDutyCycleSystemDeflection",
    "ShaftHubConnectionCompoundSystemDeflection",
    "ShaftToMountableComponentConnectionCompoundSystemDeflection",
    "SpecialisedAssemblyCompoundSystemDeflection",
    "SpiralBevelGearCompoundSystemDeflection",
    "SpiralBevelGearMeshCompoundSystemDeflection",
    "SpiralBevelGearSetCompoundSystemDeflection",
    "SpringDamperCompoundSystemDeflection",
    "SpringDamperConnectionCompoundSystemDeflection",
    "SpringDamperHalfCompoundSystemDeflection",
    "StraightBevelDiffGearCompoundSystemDeflection",
    "StraightBevelDiffGearMeshCompoundSystemDeflection",
    "StraightBevelDiffGearSetCompoundSystemDeflection",
    "StraightBevelGearCompoundSystemDeflection",
    "StraightBevelGearMeshCompoundSystemDeflection",
    "StraightBevelGearSetCompoundSystemDeflection",
    "StraightBevelPlanetGearCompoundSystemDeflection",
    "StraightBevelSunGearCompoundSystemDeflection",
    "SynchroniserCompoundSystemDeflection",
    "SynchroniserHalfCompoundSystemDeflection",
    "SynchroniserPartCompoundSystemDeflection",
    "SynchroniserSleeveCompoundSystemDeflection",
    "TorqueConverterCompoundSystemDeflection",
    "TorqueConverterConnectionCompoundSystemDeflection",
    "TorqueConverterPumpCompoundSystemDeflection",
    "TorqueConverterTurbineCompoundSystemDeflection",
    "UnbalancedMassCompoundSystemDeflection",
    "VirtualComponentCompoundSystemDeflection",
    "WormGearCompoundSystemDeflection",
    "WormGearMeshCompoundSystemDeflection",
    "WormGearSetCompoundSystemDeflection",
    "ZerolBevelGearCompoundSystemDeflection",
    "ZerolBevelGearMeshCompoundSystemDeflection",
    "ZerolBevelGearSetCompoundSystemDeflection",
)



"""CouplingHalfMultibodyDynamicsAnalysis"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5803

_COUPLING_HALF_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "CouplingHalfMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.analyses_and_results import _2944, _2946, _2950
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7943,
        _7947,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
        _5737,
        _5741,
        _5743,
        _5758,
        _5806,
        _5808,
        _5815,
        _5820,
        _5834,
        _5844,
        _5846,
        _5847,
        _5851,
        _5853,
    )
    from mastapy._private.system_model.part_model.couplings import _2869

    Self = TypeVar("Self", bound="CouplingHalfMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CouplingHalfMultibodyDynamicsAnalysis._Cast_CouplingHalfMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CouplingHalfMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CouplingHalfMultibodyDynamicsAnalysis:
    """Special nested class for casting CouplingHalfMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "CouplingHalfMultibodyDynamicsAnalysis"

    @property
    def mountable_component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5803.MountableComponentMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5803.MountableComponentMultibodyDynamicsAnalysis)

    @property
    def component_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5741.ComponentMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5741,
        )

        return self.__parent__._cast(_5741.ComponentMultibodyDynamicsAnalysis)

    @property
    def part_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5806.PartMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5806,
        )

        return self.__parent__._cast(_5806.PartMultibodyDynamicsAnalysis)

    @property
    def part_time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7947.PartTimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7947,
        )

        return self.__parent__._cast(_7947.PartTimeSeriesLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7943.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7943,
        )

        return self.__parent__._cast(_7943.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2950.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2950

        return self.__parent__._cast(_2950.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def clutch_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5737.ClutchHalfMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5737,
        )

        return self.__parent__._cast(_5737.ClutchHalfMultibodyDynamicsAnalysis)

    @property
    def concept_coupling_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5743.ConceptCouplingHalfMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5743,
        )

        return self.__parent__._cast(_5743.ConceptCouplingHalfMultibodyDynamicsAnalysis)

    @property
    def cvt_pulley_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5758.CVTPulleyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5758,
        )

        return self.__parent__._cast(_5758.CVTPulleyMultibodyDynamicsAnalysis)

    @property
    def part_to_part_shear_coupling_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5808.PartToPartShearCouplingHalfMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5808,
        )

        return self.__parent__._cast(
            _5808.PartToPartShearCouplingHalfMultibodyDynamicsAnalysis
        )

    @property
    def pulley_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5815.PulleyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5815,
        )

        return self.__parent__._cast(_5815.PulleyMultibodyDynamicsAnalysis)

    @property
    def rolling_ring_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5820.RollingRingMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5820,
        )

        return self.__parent__._cast(_5820.RollingRingMultibodyDynamicsAnalysis)

    @property
    def spring_damper_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5834.SpringDamperHalfMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5834,
        )

        return self.__parent__._cast(_5834.SpringDamperHalfMultibodyDynamicsAnalysis)

    @property
    def synchroniser_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5844.SynchroniserHalfMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5844,
        )

        return self.__parent__._cast(_5844.SynchroniserHalfMultibodyDynamicsAnalysis)

    @property
    def synchroniser_part_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5846.SynchroniserPartMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5846,
        )

        return self.__parent__._cast(_5846.SynchroniserPartMultibodyDynamicsAnalysis)

    @property
    def synchroniser_sleeve_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5847.SynchroniserSleeveMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5847,
        )

        return self.__parent__._cast(_5847.SynchroniserSleeveMultibodyDynamicsAnalysis)

    @property
    def torque_converter_pump_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5851.TorqueConverterPumpMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5851,
        )

        return self.__parent__._cast(_5851.TorqueConverterPumpMultibodyDynamicsAnalysis)

    @property
    def torque_converter_turbine_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5853.TorqueConverterTurbineMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5853,
        )

        return self.__parent__._cast(
            _5853.TorqueConverterTurbineMultibodyDynamicsAnalysis
        )

    @property
    def coupling_half_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "CouplingHalfMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CouplingHalfMultibodyDynamicsAnalysis(
    _5803.MountableComponentMultibodyDynamicsAnalysis
):
    """CouplingHalfMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _COUPLING_HALF_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def component_design(self: "Self") -> "_2869.CouplingHalf":
        """mastapy.system_model.part_model.couplings.CouplingHalf

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ComponentDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_CouplingHalfMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_CouplingHalfMultibodyDynamicsAnalysis
        """
        return _Cast_CouplingHalfMultibodyDynamicsAnalysis(self)



"""LoadedBallBearingDutyCycle"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
)

from mastapy._private._internal import constructor, utility
from mastapy._private.bearings.bearing_results import _2200
from mastapy._private.bearings.bearing_results.rolling import _2245

_LOADED_BALL_BEARING_DUTY_CYCLE = python_net_import(
    "SMT.MastaAPI.Bearings.BearingResults.Rolling", "LoadedBallBearingDutyCycle"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.bearings.bearing_results import _2189, _2197
    from mastapy._private.utility.property import _2077

    Self = TypeVar("Self", bound="LoadedBallBearingDutyCycle")
    CastSelf = TypeVar(
        "CastSelf", bound="LoadedBallBearingDutyCycle._Cast_LoadedBallBearingDutyCycle"
    )


__docformat__ = "restructuredtext en"
__all__ = ("LoadedBallBearingDutyCycle",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LoadedBallBearingDutyCycle:
    """Special nested class for casting LoadedBallBearingDutyCycle to subclasses."""

    __parent__: "LoadedBallBearingDutyCycle"

    @property
    def loaded_rolling_bearing_duty_cycle(
        self: "CastSelf",
    ) -> "_2200.LoadedRollingBearingDutyCycle":
        return self.__parent__._cast(_2200.LoadedRollingBearingDutyCycle)

    @property
    def loaded_non_linear_bearing_duty_cycle_results(
        self: "CastSelf",
    ) -> "_2197.LoadedNonLinearBearingDutyCycleResults":
        from mastapy._private.bearings.bearing_results import _2197

        return self.__parent__._cast(_2197.LoadedNonLinearBearingDutyCycleResults)

    @property
    def loaded_bearing_duty_cycle(self: "CastSelf") -> "_2189.LoadedBearingDutyCycle":
        from mastapy._private.bearings.bearing_results import _2189

        return self.__parent__._cast(_2189.LoadedBearingDutyCycle)

    @property
    def loaded_ball_bearing_duty_cycle(
        self: "CastSelf",
    ) -> "LoadedBallBearingDutyCycle":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LoadedBallBearingDutyCycle(_2200.LoadedRollingBearingDutyCycle):
    """LoadedBallBearingDutyCycle

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LOADED_BALL_BEARING_DUTY_CYCLE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def track_truncation_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TrackTruncationSafetyFactor")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def track_truncation_inner_summary(
        self: "Self",
    ) -> "_2077.DutyCyclePropertySummaryPercentage[_2245.LoadedBallBearingResults]":
        """mastapy.utility.property.DutyCyclePropertySummaryPercentage[mastapy.bearings.bearing_results.rolling.LoadedBallBearingResults]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TrackTruncationInnerSummary")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)[
            _2245.LoadedBallBearingResults
        ](temp)

    @property
    @exception_bridge
    def track_truncation_outer_summary(
        self: "Self",
    ) -> "_2077.DutyCyclePropertySummaryPercentage[_2245.LoadedBallBearingResults]":
        """mastapy.utility.property.DutyCyclePropertySummaryPercentage[mastapy.bearings.bearing_results.rolling.LoadedBallBearingResults]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "TrackTruncationOuterSummary")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)[
            _2245.LoadedBallBearingResults
        ](temp)

    @property
    def cast_to(self: "Self") -> "_Cast_LoadedBallBearingDutyCycle":
        """Cast to another type.

        Returns:
            _Cast_LoadedBallBearingDutyCycle
        """
        return _Cast_LoadedBallBearingDutyCycle(self)
